@@ -52,6 +52,7 @@ bool AgentProcessInstance::start( const AgentType &agentInfo )
   }
 
   mController = new Akonadi::ProcessControl( this );
+  connect( mController, SIGNAL(unableToStart()), SLOT(failedToStart()) );
 
   if ( agentInfo.launchMethod == AgentType::Process ) {
     QStringList arguments;
@@ -80,9 +81,13 @@ void AgentProcessInstance::cleanup()
 
 void AgentProcessInstance::restartWhenIdle()
 {
-  if ( status() == 0 ) {
-    mController->restartOnceWhenFinished();
-    quit();
+  if ( mController->isRunning() ) {
+    if ( status() == 0 ) {
+      mController->restartOnceWhenFinished();
+      quit();
+    }
+  } else {
+    mController->start();
   }
 }
 
@@ -90,3 +95,8 @@ void Akonadi::AgentProcessInstance::configure(qlonglong windowId)
 {
   controlInterface()->configure( windowId );
 }
+
+void AgentProcessInstance::failedToStart()
+{
+  statusChanged( 2 /*Broken*/, QLatin1String( "Unable to start." ) );
+}
