@@ -119,7 +119,7 @@ bool Append::commit()
     if ( !mimeType.isValid() ) {
       MimeType m( QString::fromLatin1( mt ) );
       if ( !m.insert() )
-        return failureResponse( QString::fromLatin1( "Unable to create mimetype '%1'.").arg( QString::fromLatin1( mt ) ) );
+        return failureResponse( QByteArray( "Unable to create mimetype '") +  mt + QByteArray( "'." ) );
       mimeType = m;
     }
 
@@ -135,7 +135,7 @@ bool Append::commit()
     part.setPimItemId( item.id() );
     part.setDatasize( dataSize );
 
-    QList<Part> parts;
+    QVector<Part> parts;
     parts.append( part );
 
     // If we have active preprocessors then we also set the hidden attribute
